package com.parhamdata.aliza.service;

import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestClient;
import org.springframework.beans.factory.annotation.Value;

import com.parhamdata.aliza.dto.RequestDto;
import com.parhamdata.aliza.dto.ResponseDto;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@Service
public class ChatService {
    private final String openaiUri;
    private final String openaiPath;
    private final String openaiKey;

    private RestClient restClient;

    Logger logger = LoggerFactory.getLogger(ChatService.class);

    public ChatService(@Value("${openai.uri}") String openaiUri,
                       @Value("${openai.path}") String openaiPath,
                       @Value("${openai.key}") String openaiKey) {
        this.openaiUri = openaiUri;
        this.openaiPath = openaiPath;
        this.openaiKey = openaiKey;
        logger.info("OpenAI uri: {}", openaiUri + openaiPath);
        restClient = RestClient.builder()
            .baseUrl(openaiUri)
            .build();
    }

    public ResponseDto send(RequestDto request) {
        logger.info("Posting request to: {}", openaiUri + openaiPath);
        return restClient.post()
            .uri(openaiPath)
            .header("Authorization", "Bearer " + openaiKey)
            .contentType(MediaType.APPLICATION_JSON)
            .accept(MediaType.APPLICATION_JSON)
            .body(request)
            .retrieve()
            .body(ResponseDto.class);
    }

}
